@@ -159,6 +159,7 @@ class LaunchStackTask(HastexoTask):
         self.providers = []
         for provider in stack.providers:
             p = Provider.init(provider["name"])
+            p.set_logger(logger)
             p.set_capacity(provider["capacity"])
 
             template = read_from_contentstore(
@@ -646,6 +647,7 @@ class SuspendStackTask(HastexoTask):
 
     def suspend_stack(self, stack):
         provider = Provider.init(stack.provider)
+        provider.set_logger(logger)
         provider_stack = provider.get_stack(stack.name)
 
         if provider_stack["status"] in UP_STATES + (SUSPEND_FAILED,):
@@ -653,6 +655,7 @@ class SuspendStackTask(HastexoTask):
                     stack.hook_events and
                     isinstance(stack.hook_events, dict) and
                     stack.hook_events.get("suspend", False)):
+                ssh = None
                 try:
                     # If there's a suspend hook, execute it.
                     logger.info("Fetching pre-suspend hook [%s] for stack "
@@ -672,10 +675,8 @@ class SuspendStackTask(HastexoTask):
                     logger.error("Error running pre-suspend hook for stack "
                                  "[%s]: %s" % (stack.name, error_msg))
                 finally:
-                    try:
+                    if ssh:
                         ssh.close()
-                    except Exception:
-                        pass
 
             # Suspend stack
             logger.info("Suspending stack [%s]." % stack.name)
@@ -729,6 +730,7 @@ class DeleteStackTask(HastexoTask):
         settings = get_xblock_settings()
         attempts = settings.get("delete_attempts", 3)
         provider = Provider.init(stack.provider)
+        provider.set_logger(logger)
         provider_stack = provider.get_stack(stack.name)
         attempt = 0
 
@@ -766,6 +768,7 @@ class DeleteStackTask(HastexoTask):
                         logger.info("Executing pre-delete hook for stack [%s] "
                                     "at [%s]." % (stack.name, stack.ip))
 
+                        ssh = None
                         try:
                             script = read_from_contentstore(stack.course_id,
                                                             stack.hook_script)
@@ -778,7 +781,8 @@ class DeleteStackTask(HastexoTask):
                                          "for stack [%s]: %s" %
                                          (stack.name, str(e)))
                         finally:
-                            ssh.close()
+                            if ssh:
+                                ssh.close()
 
                 try:
                     provider_stack = provider.delete_stack(stack.name)
@@ -815,12 +819,12 @@ class CheckStudentProgressTask(HastexoTask):
         for key, value in kwargs.items():
             setattr(self, key, value)
 
+        ssh = None
         try:
             # Open SSH connection to the public facing node
             ssh = ssh_to(self.stack_user_name,
                          self.stack_ip,
                          self.stack_key)
-
             # Run tests on the stack
             res = self.run_tests(ssh)
         except (RemoteExecTimeout, SoftTimeLimitExceeded):
@@ -829,8 +833,9 @@ class CheckStudentProgressTask(HastexoTask):
                 'error': True
             }
         finally:
-            # Close the connection
-            ssh.close()
+            if ssh:
+                # Close the connection
+                ssh.close()
 
         return res
 
